@@ -76,7 +76,7 @@ MAPBOX_ACCESSTOKEN = env('MAPBOX_ACCESSTOKEN',
 from .languages import *
 
 # meta
-META_DESCRIPTION = env('META_DESCRIPTION', default=APP_DOMAIN)
+META_DESCRIPTION = env('META_DESCRIPTION', default='Django SSO app')
 META_SITE_PROTOCOL = ACCOUNT_DEFAULT_HTTP_PROTOCOL
 META_USE_SITES = True
 META_SITE_DOMAIN = APP_DOMAIN
@@ -399,18 +399,6 @@ LOGGING = {
         }
     },
     "root": {"level": "DEBUG", "handlers": ["console"]},
-    'loggers': {
-        'django': {
-            'handlers': ['console'],
-            'level': os.getenv('DJANGO_LOG_LEVEL', 'INFO'),
-            'propagate': False,
-        },
-        'environ': {
-            'handlers': ['console'],
-            'level': os.getenv('DJANGO_LOG_LEVEL', 'INFO'),
-            'propagate': False,
-        },
-    },
 }
 
 # Celery
