@@ -26,3 +26,13 @@ class UserTestCase(UserTestCase):
         profile.refresh_from_db()
 
         self.assertEqual(profile.sso_rev, profile_rev + 1)
+
+    def test_user_creation_adds_default_groups(self):
+        group_name = self._get_random_string()
+
+        with self.settings(DJANGO_SSO_APP_DEFAULT_USER_GROUPS=[group_name]):
+            user = self._get_new_user()
+
+            user_groups = user.groups.values_list('name', flat=True)
+
+            assert group_name in user_groups
