@@ -5,7 +5,7 @@ import sys
 
 
 def main():
-    os.environ.setdefault('DJANGO_SETTINGS_MODULE', 'django_sso_app.backend.config.settings.local')
+    os.environ.setdefault('DJANGO_SETTINGS_MODULE', 'django_sso_app.config.settings.local')
     try:
         from django.core.management import execute_from_command_line
     except ImportError as exc:
